CedarPersistenceError

Enum CedarPersistenceError 

#[non_exhaustive]
pub enum CedarPersistenceError { Io(Error), Truncated, InvalidMagic, UnsupportedVersion { major: u16, minor: u16, }, UnsupportedByteOrder { byte_order: u8, }, LayoutMismatch { expected: u8, found: u8, }, InvalidHeader { field: &'static str, value: u64, }, AllocationLimitExceeded { requested: usize, limit: usize, }, AllocationFailed { requested: usize, }, CorruptData { section: &'static str, index: usize, reason: &'static str, }, TrailingData, }
Errors returned while saving or loading cedarwood’s versioned binary format.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(Error)

The underlying stream or filesystem operation failed.



Truncated

The input ended before the complete declared representation was read.



InvalidMagic

The eight-byte cedarwood format marker did not match.



UnsupportedVersion

The file uses a format version this reader does not understand.

Fields

major: u16
minor: u16


UnsupportedByteOrder

The file is not explicitly marked as little-endian.

Fields

byte_order: u8


LayoutMismatch

The file was produced for a different compile-time trie layout.

Fields

expected: u8
found: u8


InvalidHeader

Reserved header flags were set or a header field was otherwise invalid.

Fields

field: &'static str
value: u64


AllocationLimitExceeded

Loading and structural validation would reserve more memory than the caller allows.

Fields

requested: usize
limit: usize


AllocationFailed

The allocator could not reserve the validated amount of memory.

Fields

requested: usize


CorruptData

A structural invariant failed validation.

Fields

section: &'static str
index: usize
reason: &'static str


TrailingData

Bytes remained after the complete declared representation.